/***************************************************************************
                          game.h  -  description
                             -------------------
    begin                : Sat Jan 1 2000
    copyright            : (C) 2000 by Perdig
    email                : perdig@linuxbr.com.br

    $Id: game.h,v 1.5 2001/01/01 18:49:16 perdig Exp $
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/
#ifndef _GAME_H
#define _GAME_H

#include "config.h"
#include "global.h"

// Geometry variables

#define MAP_WIDTH (SPRITE_SIZE * TILE_WIDTH)
#define MAP_HEIGHT (SPRITE_SIZE * TILE_HEIGHT)

#define FUEL_WIDTH 134
#define FUEL_HEIGHT 10

#define RADAR_WIDTH (FUEL_WIDTH)
#define RADAR_HEIGHT (MAP_HEIGHT / 2)

#define MIDDLE_X (MAP_WIDTH / 2)
#define MIDDLE_Y (MAP_HEIGHT / 2)

#define RADAR_X (MAP_WIDTH + 4)
#define RADAR_Y ((MAP_HEIGHT / 2) + 2)

#define SCORE_WIDTH (FUEL_WIDTH)
#define SCORE_HEIGHT (MAP_HEIGHT - RADAR_HEIGHT - 50)

#define SCORE_X (MAP_WIDTH + 4)
#define SCORE_Y (2)

#define FUEL_X (MAP_WIDTH + 2)
#define FUEL_Y (SCORE_Y + SCORE_HEIGHT - FUEL_HEIGHT - 2)

#define WINDOW_WIDTH (MAP_WIDTH + SCORE_WIDTH)
#define WINDOW_HEIGHT (MAP_HEIGHT)



// Define Icon name
#define ICON_NAME ""

// Define Number of Pics
#define PIXS 5
#define CARS 2

// Define each Pic
#define ROAD 0
#define BLOCK 1
#define OUT 2
#define FLAG 3
#define PIT 4

// Custom from 4 to 8 -> passable
// Custom from 9 to 13 -> impassable
#define RED 0
#define BLUE 1

// Radar modes
#define ORIGINAL 0
#define SONAR 1
#define FUELSONAR 2
#define FULL 3

// Load game pixmap macro
#define LOAD_GAME_PIXMAP(TILE, MASK, FILENAME) do { \
		a = load_pixmap(TILE, MASK, FILENAME, &w, &h); \
		if (a != 0) { \
			dbg("Can't find %s on %s tileset. Loading the default", FILENAME, level.tileset); \
			chdir("../default"); \
			a = load_pixmap(TILE, MASK, FILENAME, &w, &h); \
			chdir(".."); \
			chdir(level.tileset); \
		} \
		if (a == 0 && (w != rw || h != rh)) \
			dbg("%s's size is %d/%d, and not %d/%d as expected", FILENAME, w, h, rw, rh); \
		update_splash(); \
	} while(0)

// Radar bit: Size of flags and cars on the radar
#define RADARBIT ((int)(toMap(1) * radar.factor))

// Functions

int load_images();
void draw_window(int x, int y, int w, int h);
void draw_map(mapStruct *Map);
void draw_car(carStruct *car);
void draw_ai(aiStruct *ai);
void draw_smoke();
void draw_radar(int mode, int range);
void draw_info_bar();
void draw_light(int light);
bool in_radar(int x, int y, int carX, int carY, int range);
void process_input(KeySym key);
void fix_geometry(int size);
void init_screen();
void clean_info_bar();

#endif
